==> ScriptDeploy-0.4.tar: ScriptDeploy-0.4/action.defaultadmin.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
if (!isset($gCms)) exit;

#
#The tab headers
#
echo '<script type="text/javascript">
//<![CDATA[
load = function() {
    load.getScript("http://ajax.microsoft.com/ajax/jQuery/jquery-1.3.2.min.js");
    // do stuff when jQuery finishes loading.
    load.tryReady(0);
}
load.getScript = function(filename) {
    var fileref = document.createElement("script")
    fileref.setAttribute("type","text/javascript")
    fileref.setAttribute("src", filename)
    if (typeof fileref!="undefined")
        document.getElementsByTagName("head")[0].appendChild(fileref)
}
load.tryReady = function(time_elapsed) {
    /* Continually polls for jQuery library. */
    if (typeof $ == "undefined") {
        if (time_elapsed <= 5000) {
            setTimeout("load.tryReady(" + (time_elapsed + 200) + ")", 200);
        } else {
            alert("Timed out while loading jQuery.")
        }
    }
}
if (typeof(window.jQuery)=="undefined"){
		load();   
}

	//]]>

</script>

<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="http://cdn.jquerytools.org/1.1.2/tiny/jquery.tools.min.js"></script>
<script src="http://ajax.microsoft.com/ajax/jquery.validate/1.6/jquery.validate.min.js" type="text/javascript"></script>
<script type="text/javascript" src="../modules/ScriptDeploy/includes/ME_1.00.00.js"></script>


<div id="demotip">&nbsp;</div>

';



if (FALSE == empty($params['active_tab'])){
	$tab = $params['active_tab'];
} else {
	$tab = '';
}
$tabIs=0;
if ($tab=="script_template"){$tabIs=0;}
if ($tab=="manualassignment"){$tabIs=1;}
if ($tab=="options"){$tabIs=2;}
echo '<script type="text/javascript">$(document).ready(function(){$("ul.tabers").tabs("div.Tabpanes > div.pane", {effect: "fade", fadeOutSpeed: 200, initialIndex:'.$tabIs.', onClick:function(event, tabIndex) {if ($(".pagemessage").length > 0){$(".pagemessage").closest(".pagemcontainer").fadeOut(2000,function(){$(".pagemessage").closest(".pagemcontainer").remove();});}}}); });</script>';
 
if (FALSE == empty($params['active_tab']) && FALSE == empty($params['tab_message'])) {
	$message = $this->ShowMessage($this->Lang($params['tab_message']));
} else {
	$message = '';
}
echo $message;
if ($this->CheckPermission('Modify Calendar')){
echo'
<ul class="tabers">
	<li><a href="#script_template">'.$this->Lang('Script_list').'</a></li>
	<li><a href="#manualassignment">'.$this->Lang('manualassignment').'</a></li>
	<li><a href="#options">'.$this->Lang('ACToptions').'</a></li>
</ul> 
';
}
  
if ($this->CheckPermission('Modify Calendar'))
  {
echo '<div class="Tabpanes" id="PPBM">
<div class="pane">';
      echo '<h3>'.$this->Lang('title_Scripts').'</h3>';
      $this->_AdminCreateTemplateList($id,$returnid,
				      'email',
				      'default_script_template_contents',
				      'script_template',
				      'current_script_template',
				      $this->Lang('title_script_template'));
echo '</div>
<div class="pane">';
      echo '<h3>'.$this->Lang('title_Groups').'</h3>';
      $this->_AdminCreateAssignmentList($id,$returnid,
				      'email',
				      'default_script_template_contents',
				      'manualassignment',
				      'current_script_template',
				      $this->Lang('title_script_template'));
echo '</div>
<div class="pane">';
    include(dirname(__FILE__).'//function.admin_ACToptionstab.php');
	  echo '</div>
	</div>';
}
















# vim:ts=4 sw=4 noet
?>

==> ScriptDeploy-0.5.tar: ScriptDeploy-0.5/action.defaultadmin.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/ScriptDeploy/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------
if (!isset($gCms)) exit;

#
#The tab headers
#
echo '<script type="text/javascript">
//<![CDATA[
load = function() {
    load.getScript("http://ajax.microsoft.com/ajax/jQuery/jquery-1.3.2.min.js");
    // do stuff when jQuery finishes loading.
    load.tryReady(0);
}
load.getScript = function(filename) {
    var fileref = document.createElement("script")
    fileref.setAttribute("type","text/javascript")
    fileref.setAttribute("src", filename)
    if (typeof fileref!="undefined")
        document.getElementsByTagName("head")[0].appendChild(fileref)
}
load.tryReady = function(time_elapsed) {
    /* Continually polls for jQuery library. */
    if (typeof $ == "undefined") {
        if (time_elapsed <= 5000) {
            setTimeout("load.tryReady(" + (time_elapsed + 200) + ")", 200);
        } else {
            alert("Timed out while loading jQuery.")
        }
    }
}
if (typeof(window.jQuery)=="undefined"){
		load();   
}

	//]]>

</script>

<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="http://cdn.jquerytools.org/1.1.2/tiny/jquery.tools.min.js"></script>
<script src="http://ajax.microsoft.com/ajax/jquery.validate/1.6/jquery.validate.min.js" type="text/javascript"></script>
<script type="text/javascript" src="../modules/ScriptDeploy/includes/ME_1.00.00.js"></script>
<div id="demotip">&nbsp;</div>

';



if (FALSE == empty($params['active_tab'])){
	$tab = $params['active_tab'];
} else {
	$tab = '';
}
$tabIs=0;
if ($tab=="script_template"){$tabIs=0;}
if ($tab=="manualassignment"){$tabIs=1;}
if ($tab=="htmlsettings"){$tabIs=2;}
if ($tab=="options"){$tabIs=3;}
echo '<script type="text/javascript">$(document).ready(function(){$("ul.tabers").tabs("div.Tabpanes > div.pane", {effect: "fade", fadeOutSpeed: 200, initialIndex:'.$tabIs.', onClick:function(event, tabIndex) {if ($(".pagemessage").length > 0){$(".pagemessage").closest(".pagemcontainer").fadeOut(3500,function(){$(".pagemessage").closest(".pagemcontainer").remove();});}}}); });</script>';
 
if (FALSE == empty($params['active_tab']) && FALSE == empty($params['tab_message'])) {
	$message = $this->ShowMessage($this->Lang($params['tab_message']));
} else {
	$message = '';
}
echo $message;
if ($this->CheckPermission('Modify Site Preferences')){
echo'
<ul class="tabers">
	<li><a href="#script_template">'.$this->Lang('Script_list').'</a></li>
	<li><a href="#manualassignment">'.$this->Lang('manualassignment').'</a></li>
	<li><a href="#htmlsettings">'.$this->Lang('HTMLsettings').'</a></li>
	<li><a href="#options">'.$this->Lang('ACToptions').'</a></li>
</ul> 
';
}
  
if ($this->CheckPermission('Modify Site Preferences'))
  {
echo '<div class="Tabpanes" id="PPBM">
<div class="pane">';
      echo '<h3>'.$this->Lang('title_Scripts').'</h3>';
      $this->_AdminCreateTemplateList($id,$returnid,
				      'email',
				      'default_script_template_contents',
				      'script_template',
				      'current_script_template',
				      $this->Lang('title_script_template'));
echo '</div>
<div class="pane">';
      echo '<h3>'.$this->Lang('title_Groups').'</h3>';
      $this->_AdminCreateAssignmentList($id,$returnid,
				      'email',
				      'default_script_template_contents',
				      'manualassignment',
				      'current_script_template',
				      $this->Lang('title_script_template'));
echo '</div>
<div class="pane">';
    include(dirname(__FILE__).'//function.admin_HTMLtab.php');
	
echo '</div>
<div class="pane">';
    include(dirname(__FILE__).'//function.admin_ACToptionstab.php');
	  echo '</div>
	</div>';
}
















# vim:ts=4 sw=4 noet
?>
